#
# spec file for package python-ligo-lw
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%bcond_without test
%define psuffix -test
%else
%bcond_with test
%define psuffix %{nil}
%endif

%define bins ligolw_add ligolw_cut ligolw_no_ilwdchar ligolw_print ligolw_segments ligolw_sqlite ligolw_run_sqlite
%define srcname python-ligo-lw
Name:           python-ligo-lw%{?psuffix}
Version:        1.8.3
Release:        6.1
Summary:        Python LIGO Light-Weight XML I/O Library
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://git.ligo.org/kipp/python-ligo-lw
Source:         http://software.ligo.org/lscsoft/source/%{srcname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM ligo-lw-segments-test-fix.patch badshah400@gmail.com -- Fix a test that randomly fails due to dictionary ordering being undefined
Patch0:         ligo-lw-segments-test-fix.patch
# PATCH-FIX-UPSTREAM ligo-lw-disable-doctests.patch badshah400@gmail.com -- Disable doctests as these are not ready for py 3.10 yet
Patch1:         ligo-lw-disable-doctests.patch
# PATCH-FIX-OPENSUSE ligo-lw-disable-sqlite-test.patch badshah400@gmail.com -- Disable sqlite test that requires network resources
Patch3:         ligo-lw-disable-sqlite-test.patch
# https://git.ligo.org/kipp.cannon/python-ligo-lw/-/commit/693cfc4d4759c1984609effa1dde810a192fe94f
Patch4:         python-ligo-lw-no-python2.patch
# PATCH-FIX-UPSTREAM badshah400@gmail.com -- https://git.ligo.org/kipp/python-ligo-lw/-/issues/29
Patch5:         ligo-lw-python3.12-compat.patch
# PATCH-FIX-UPSTREAM ligo-lw-disable-lsctables.patch badshah400@gmail.com -- Disable failing lsctables test due to "SystemError: error return without exception set"
Patch6:         ligo-lw-disable-lsctables.patch
# PATCH-FIX-UPSTREAM ligo-lw-disable-utils_segments.patch badshah400@gmail.com -- Disable failing utils_segments test (temporary workaround to get builds to succeed)
Patch7:         ligo-lw-disable-utils_segments.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-lal
Requires:       python-ligo-segments
Requires:       python-lscsoft-glue
Requires:       python-numpy
Requires:       python-python-dateutil
Requires:       python-tqdm
Requires(post): update-alternatives
Requires(postun): update-alternatives
# lal no longer supported for 32bit, and is a hard dependency for ligo-lw
ExcludeArch:    %{ix86}
# SECTION Test requirements
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module lal}
BuildRequires:  %{python_module ligo-lw = %{version}}
BuildRequires:  %{python_module ligo-segments}
BuildRequires:  %{python_module lscsoft-glue}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module tqdm}
BuildRequires:  diffutils
BuildRequires:  libxml2-tools
BuildRequires:  python3
%endif
# /SECTION
%python_subpackages

%description
The LIGO Light-Weight XML format is used extensively by compact object
detection pipeline and associated tool sets.  This package provides a Python
I/O library for reading, writing, and interacting with documents in this
format.

%prep
%autosetup -p1 -n %{srcname}-%{version}
# Replace distutils.core by setuptools to fix namespace errors
# https://git.ligo.org/kipp.cannon/python-ligo-lw/-/issues/16
sed -i "1{s/distutils.core/setuptools/}" setup.py

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%{lua: for c in string.gmatch(rpm.expand("%bins"), "%S+") do
  print(rpm.expand("%python_clone -a %{buildroot}%{_bindir}/" .. c .. "\n"))
end}
%endif

%check
%if %{with test}
# Test-suite works only for python3 flavors
%{python_expand export PYTHON=$python
export PYTHONDONTWRITEBYTECODE=1
cp -r test test-%{$python_bin_suffix}
pushd test-%{$python_bin_suffix}
%make_build check
popd
}
%endif

%if %{without test}
%post
%python_install_alternative %bins

%postun
%python_uninstall_alternative %bins

%files %{python_files}
%license LICENSE
%{lua: for c in string.gmatch(rpm.expand("%bins"), "%S+") do
  print(rpm.expand("%python_alternative %{_bindir}/" .. c .. "\n"))
end}
%{python_sitearch}/ligo/
%{python_sitearch}/python_ligo_lw-%{version}.dist-info
%{python_sitearch}/python_ligo_lw-%{version}-py%{python_version}-nspkg.pth
%endif

%changelog
* Wed Jun 18 2025 Steve Kowalik <steven.kowalik@suse.com>
- Use pyproject macros to build and install.
- Update URL.
* Sun Jan 19 2025 Atri Bhattacharya <badshah400@gmail.com>
- Add patches to disable failing tests (temporary workaround until
  we or upstream actually fix the test suite):
  * ligo-lw-disable-lsctables.patch
  * ligo-lw-disable-utils_segments.patch
* Thu Aug 29 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update ligo-lw-python3.12-compat.patch with more
  `PyObject_HEAD_INIT` fixes.
* Tue Aug 27 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add ligo-lw-python3.12-compat.patch: Change `PyObject_HEAD_INIT`
  to `PyVarObject_HEAD_INIT` for compatibilty with python 3.12 and
  GCC 14 (https://git.ligo.org/kipp/python-ligo-lw/-/issues/29).
- Re-enable build for python 3.12.
* Thu Aug 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Disable python 3.12 builds as codebase is not ready:
  https://git.ligo.org/kipp/python-ligo-lw/-/issues/29
* Mon Mar 13 2023 pgajdos@suse.com
- do not require python-six
- added patches
  https://git.ligo.org/kipp.cannon/python-ligo-lw/-/commit/693cfc4d4759c1984609effa1dde810a192fe94f
  + python-ligo-lw-no-python2.patch
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.3:
  * ligolw_run_sqlite: update for dbtables API changes.
- Changes from version 1.8.2:
  * ligolw_segments: fix python 3 print statements.
- Changes from version 1.8.1:
  * ligolw_segments: fix AttributeError.
  * remove ilwd from list of modules in __init__.py.
  * bump debian/compat to 10.
  * fix an invalid type in the demo document used for testing
    (real8 --> real_8).
  * correct release date and time for 1.8.0.
* Tue Mar 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Disable 32-bit builds as lal, a dependency of this, no longer
  supports those archs.
* Wed Jan 12 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add patches to disable tests that either will not work in an
  OBS setting or are temporarily incompatible with Python 3.10:
  * ligo-lw-disable-doctests.patch: Disable doctests as these are
    not ready for py 3.10 yet.
  * ligo-lw-disable-sqlite-test.patch: Disable sqlite test that
    requires network resources.
* Wed Jan 12 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.0:
  * Adjust dbtables.workingcopy error path behaviour.
  * Remove dbtables.workingcopy compatibility code.
  * Remove gz= compatibility keyword argument from I/O functions.
  * Remove ligo-common from python3 requirements.
  * Update dependencies in .spec file for RPM systems.
  * ligo.LIGO_LW add .get_ligo_lw() class method.
  * Expand test suite coverage.
  * lsctables.SimInspiral generalize SNR related methods to
    complex values.
  * Switch test suite to python3 (python2 no longer covered by
    test suite).
  * Remove ilwd support code, use native strings for this type.
  * process.py remove set_process_end_time() function.
  * table.py remove get_table() function.
  * param.Param introduce .value.
  * param.Param introduce .get_param() class method.
  * array.Array introduce .get_array() class method.
  * ligolw_sqlite remove unused setup() function.
  * dbtables collect ID remapping code into a class.
  * Tokenizer drop use in Py_UNICODE in favour of wchar_t.
  * Tokenizer no longer allow quoted delimiters to be escaped.
  * load_url() expose context and timeout keyword arguments.
  * Add ligolw_run_sqlite (migrated from lalapps).
  * Add support for .bz2 and .xz compression formats.
- Add ligolw_run_sqlite to list of bins processed by update
  alternatives and installed for multiple py3 versions.
* Wed Apr 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Skip python2: dependency ligo-segments no longer supports
  python2.
* Sat Feb 13 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: Due to NEP 29, python36-scipy in TW is no
  more. Numpy and the lal packages follow
* Thu Jan 21 2021 Atri Bhattacharya <badshah400@gmail.com>
- Fix up tests and binary installation to account for multiple
  python versions.
- Use mutibuild to split up main pkg building and tests since
  tests require the binaries which are installed using
  /etc/alternatives.
* Fri Oct 30 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.7.0:
  * Replace gz= keyword with compress= and expand auto format
    detection features.
  * Implement ligolw_no_ilwdchar as a module for reuse.
  * Move programs into separate -bin package on Debian.
  * Expand SimInspiral row type:  add methods to compute effective
    distance instead of relying on columns with these numbers
    precomputed;  doing this to allow analysis codes to add
    support for KAGRA in a way that is uniform across detectors.
  * Remove table.Table._end_of_rows() hook.
  * Reimplement most of ligo.lw.utils.process as methods and
    feature improvements within Process and ProcessParams row
    types.
  * Do the same for SearchSummary.
  * Array.Array:  add .shape property.
  * Add support for +/-inf to lsctables.gpsproperty_with_gmst.
  * Convert C modules to native Python 2 & 3 versions and remove
    six.h from build.
  * Switch test suite to Python 3.  adds xmllint build dependency
    because Python 3 can't be relied upon to produce consistent
    XML output.
  * Add test of ligolw_sqlite's --tmp-space feature.
  * Fix ligolw_sqlite's --tmp-space feature on Python 3 by
    converting working copy mechanism to a context handler which
    does its own clean-up, instead of hooking into the guts of
    NamedTemporaryFile.
  * Various documentation improvements, including new
    documentation to expand doctest based test suite coverage.
  * Replace glue.text_progress_bar with tqdm (new dependency).
- Run tests as part of %%check section (python3 and 64-bit only);
  include all Requires as BuildRequires, plus diffutils (for cmp),
  libxml2-tools (for xmllint), python3, and python-matplotlib.
- Replace the use of "distutils.core" with "setuptools"; ligo.lw
  module is not found when the former is used (see
  https://git.ligo.org/kipp.cannon/python-ligo-lw/-/issues/16).
- Add ligo-lw-segments-test-fix.patch to fix a test that randomly
  fails due to dictionary ordering being undefined (sent
  upstream).
- Update URL: previous URL no longer accessible.
- New Requires: python-tqdm.
* Sat Aug 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Drop unnecessary BuildRequires python-ligo-common and
  python-lalburst.
* Wed May 27 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * Remove custom ProcessParamsTable from dbtables.
  * Remove .update_column_info() method from table.Table.
  * Remove abandoned experiment tables from lsctables.
  * Remove unused "interning" feature from RowBuilder.
  * Improve start/stop attribute handling in a variety of
    lsctables row and table types.
  * (re-)fix printing null-valued table cells in ligolw_print.
  * Some test suite and packaging updates.
- Add Requires: python-python-dateutil.
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.2:
  * fix typo in lsctables.py
  * disable unit tests during .deb build
  * fix quoting of version string in .rpm
- Changes from version 1.5.1:
  * load_filename() load_url():  close files
  * add missing python-dateutil dependency
  * don't require lalburst, just recommend it
  * add glue-ligolw-tools clean-up deps for python 3
- Changes from version 1.5.0:
  * port Leo's Python 3 doctest fixes from glue that had been left
    behind
  * build script fixes
  * restore ligolw_segments to this package
  * update for offsetvector's move to lalburst (adds lalburst
    dependency)
- Add BuildRequires: python-lalburst.
* Fri Feb  8 2019 badshah400@gmail.com
- Initial package.
